@@ -20,6 +20,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 重复的订单，请检查emr控制台。
 FAILEDOPERATION_DUPLICATEORDERNOTALLOWED = 'FailedOperation.DuplicateOrderNotAllowed'
 
+# 操作失败，不支持pod。
+FAILEDOPERATION_NOTSUPPORTPOD = 'FailedOperation.NotSupportPod'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -86,6 +89,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 展示策略错误。
 INVALIDPARAMETER_DISPLAYSTRATEGYNOTMATCH = 'InvalidParameter.DisplayStrategyNotMatch'
 
+# 参数错误。
+INVALIDPARAMETER_HALESSMASTERCOUNT = 'InvalidParameter.HALessMasterCount'
+
 # Common节点数量无效。
 INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'
 
@@ -146,6 +152,9 @@ INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'
 # 无效的集群保留策略。
 INVALIDPARAMETER_INVALIDINSTANCEPOLICY = 'InvalidParameter.InvalidInstancePolicy'
 
+# 无效的机型。
+INVALIDPARAMETER_INVALIDINSTANCETYPE = 'InvalidParameter.InvalidInstanceType'
+
 # 无效的流程任务。
 INVALIDPARAMETER_INVALIDJOBFLOW = 'InvalidParameter.InvalidJobFlow'
 
@@ -305,6 +314,9 @@ RESOURCENOTFOUND_TKEPRECONDITIONNOTFOUND = 'ResourceNotFound.TKEPreconditionNotF
 # 没有查找到指定标签。
 RESOURCENOTFOUND_TAGSNOTFOUND = 'ResourceNotFound.TagsNotFound'
 
+# 当前资源规格不存在默认规格。
+RESOURCEUNAVAILABLE_RESOURCESPECNOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpecNotDefaultSpec'
+
 # 当前资源规格不存在默认规格。
 RESOURCEUNAVAILABLE_RESOURCESPEC_NOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpec_NotDefaultSpec'
 
